@@ -20,9 +20,10 @@
 ##############################################################################
 """The `oerplib` module defines the :class:`OERP` class.
 
-The :class:`OERP` class manage the client-side operations which are related to
-an `OpenERP` server. You can use this one to write `Python` programs that
-performs a variety of automated jobs that communicate with an `OpenERP` server.
+The :class:`OERP` class is the entry point to manage `OpenERP/Odoo` servers.
+You can use this one to write `Python` programs that
+performs a variety of automated jobs that communicate with a
+`OpenERP/Odoo` server.
 
 You can load a pre-configured :class:`OERP` session with the :func:`load`
 function.
@@ -31,7 +32,7 @@ function.
 __author__ = 'ABF Osiell - Sebastien Alix'
 __email__ = 'sebastien.alix@osiell.com'
 __licence__ = 'LGPL v3'
-__version__ = '0.8.1'
+__version__ = '0.8.2'
 
 #__all__ = ['OERP', 'error']
 
